package jdk.internal.util.xml;

import jdk.internal.org.xml.sax.XMLReader;
import java.io.File;
import java.io.IOException;
import jdk.internal.org.xml.sax.SAXException;
import jdk.internal.org.xml.sax.InputSource;
import jdk.internal.org.xml.sax.helpers.DefaultHandler;
import java.io.InputStream;

public abstract class SAXParser
{
    protected SAXParser() {
    }
    
    public void parse(InputStream byteStream, DefaultHandler defaultHandler) throws SAXException, IOException {
        if (byteStream == null) {
            throw new IllegalArgumentException("InputStream cannot be null");
        }
        this.parse(new InputSource(byteStream), defaultHandler);
        return;
    }
    
    public void parse(String systemId, DefaultHandler defaultHandler) throws SAXException, IOException {
        if (systemId == null) {
            throw new IllegalArgumentException("uri cannot be null");
        }
        this.parse(new InputSource(systemId), defaultHandler);
        return;
    }
    
    public void parse(File file, DefaultHandler defaultHandler) throws SAXException, IOException {
        if (file == null) {
            throw new IllegalArgumentException("File cannot be null");
        }
        this.parse(new InputSource(file.toURI().toASCIIString()), defaultHandler);
        return;
    }
    
    public void parse(InputSource inputSource, DefaultHandler defaultHandler) throws SAXException, IOException {
        if (inputSource == null) {
            throw new IllegalArgumentException("InputSource cannot be null");
        }
        XMLReader xmlReader = this.getXMLReader();
        if (defaultHandler != null) {
            xmlReader.setContentHandler(defaultHandler);
            xmlReader.setEntityResolver(defaultHandler);
            xmlReader.setErrorHandler(defaultHandler);
            xmlReader.setDTDHandler(defaultHandler);
        }
        xmlReader.parse(inputSource);
        return;
    }
    
    public abstract XMLReader getXMLReader() throws SAXException;
    
    public abstract boolean isNamespaceAware();
    
    public abstract boolean isValidating();
    
    public boolean isXIncludeAware() {
        throw new UnsupportedOperationException("This parser does not support specification \"" + this.getClass().getPackage().getSpecificationTitle() + "\" version \"" + this.getClass().getPackage().getSpecificationVersion() + "\"");
    }
}
